<?php

/**
 * @file
 * Provides Deepl Pro translator ui controller.
 */

/**
 * Deepl Pro translator ui controller.
 */
class TMGMTDeeplProTranslatorUIController extends TMGMTDefaultTranslatorUIController {

  /**
   * Overrides TMGMTDefaultTranslatorUIController::pluginSettingsForm().
   */
  public function pluginSettingsForm($form, &$form_state, TMGMTTranslator $translator, $busy = FALSE) {

    $form['auth_key'] = array(
      '#type' => 'textfield',
      '#title' => t('DeepL Pro authentication key'),
      '#default_value' => $translator->getSetting('auth_key'),
      '#description' => t('Please enter your DeepL Pro authentication key or visit <a href="@url">DeepL Pro registration</a> to create new one.',
        array('@url' => 'https://www.deepl.com/pro.html')),
      '#required' => TRUE,
    );

    $form['url'] = array(
      '#type' => 'value',
      '#value' => $translator->getSetting('url'),
    );

    $form['url_usage'] = array(
      '#type' => 'value',
      '#value' => $translator->getSetting('url_usage'),
    );

    // Additional query options.
    $form['tag_handling'] = array(
      '#type' => 'textfield',
      '#title' => t('Tag handling'),
      '#description' => t('Sets which kind of tags should be handled. Comma-separated list of one or more of the following values: "xml"'),
      '#default_value' => !empty($translator->getSetting('tag_handling')) ? $translator->getSetting('tag_handling') : '',
    );

    $form['non_splitting_tags'] = array(
      '#type' => 'textfield',
      '#title' => t('Non-splitting tags'),
      '#description' => t('Comma-separated list of XML tags which never split sentences.'),
      '#default_value' => !empty($translator->getSetting('non_splitting_tags')) ? $translator->getSetting('non_splitting_tags') : '',
    );

    $form['ignore_tags'] = array(
      '#type' => 'textfield',
      '#title' => t('Ignore tags'),
      '#description' => t('Comma-separated list of XML tags whose content is never translated.'),
      '#default_value' => !empty($translator->getSetting('ignore_tags')) ? $translator->getSetting('ignore_tags') : '',
    );

    $split_split_sentences = $translator->getSetting('split_sentences');
    $form['split_sentences'] = array(
      '#type' => 'select',
      '#title' => t('Split sentences'),
      '#options' => array(
        '0' => t('Disabled'),
        '1' => t('Enabled (default)'),
      ),
      '#description' => t('Sets whether the translation engine should first split the input into sentences.'),
      '#default_value' => isset($split_split_sentences) ? $split_split_sentences : 1,
      '#required' => TRUE,
    );

    $preserve_formatting = $translator->getSetting('preserve_formatting');
    $form['preserve_formatting'] = array(
      '#type' => 'select',
      '#title' => t('Preserve formatting'),
      '#options' => array(
        '0' => t('Disabled (default)'),
        '1' => t('Enabled'),
      ),
      '#description' => t('Sets whether the translation engine should preserve some aspects of the formatting, even if it would usually correct some aspects.'),
      '#default_value' => isset($preserve_formatting) ? $preserve_formatting : 0,
      '#required' => TRUE,
    );

    return parent::pluginSettingsForm($form, $form_state, $translator);
  }

  /**
   * {@inheritdoc}
   */
  public function checkoutSettingsForm($form, &$form_state, TMGMTJob $job) {
    // Add auto_accept to checkout form.
    $form['auto_accept'] = array(
      '#type' => 'checkbox',
      '#title' => t('Auto accept finished translations'),
      '#description' => t('This skips the reviewing process and automatically accepts all translations as soon as they are returned by the translation provider.'),
      '#default_value' => ($job->getSetting('auto_accept')) ? TRUE : FALSE,
    );

    return parent::checkoutSettingsForm($form, $form_state, $job);
  }

}
